@@ -25,7 +25,7 @@ Implementation Notes
 
 import displayio
 
-__version__ = "1.1.13"
+__version__ = "1.1.14"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_IL0398.git"
 
 # TODO: Try LUTs from:
@@ -50,7 +50,7 @@ _STOP_SEQUENCE = (
 class IL0398(displayio.EPaperDisplay):
     """IL0398 driver"""
 
-    def __init__(self, bus, **kwargs):
+    def __init__(self, bus: displayio.FourWire, **kwargs) -> None:
         start_sequence = bytearray(_START_SEQUENCE)
 
         width = kwargs["width"]
